<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

do_action( 'woocommerce_before_checkout_form', $checkout );

// If checkout registration is disabled and not logged in, the user cannot checkout
if ( ! $checkout->enable_signup && ! $checkout->enable_guest_checkout && ! is_user_logged_in() ) {
    echo esc_html( apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'woocommerce' ) ) );
    return;
}

// filter hook for include new pages inside the payment method
$get_checkout_url = apply_filters( 'woocommerce_get_checkout_url', wc_get_checkout_url() ); ?>

    <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( $get_checkout_url ); ?>">

        <?php if ( sizeof( $checkout->checkout_fields ) > 0 ) : ?>

            <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

            <div class="row" id="customer_details">


                <div class="col-sm-8 details">

                    <?php do_action('yit_before_checkout_address'); ?>

                    <div class="col-1">

                        <?php do_action( 'woocommerce_checkout_billing' ); ?>

                    </div>

                    <div class="col-2">

                        <?php do_action( 'woocommerce_checkout_shipping' ); ?>

                    </div>

                </div>

                <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>


                <div class="col-sm-4">

                    <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                    <div id="review-order-wrapper" class="border" >
                        <div id="order_review" class="woocommerce-checkout-review-order">
                            <h2 id="order_review_heading"><?php esc_html_e( 'Your order', 'woocommerce' ); ?></h2>
                            <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                        </div>
                    </div>

                    <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
                </div>


            </div>

        <?php endif; ?>

    </form>


<?php do_action( 'woocommerce_after_checkout_form', $checkout ); ?>